@@ -552,6 +552,11 @@ void StartupStuff(void)
   checkPanFrames();
 #endif
 
+  /* migo (02-Oct-1999): execute StartFunction */
+  if (FindPopup("StartFunction")) {
+    ExecuteFunction("Function StartFunction", NULL, &Event, C_ROOT, -1);
+  }
+
   if(Restarting)
   {
     mr = FindPopup("RestartFunction");
@@ -1387,7 +1392,7 @@ void InitVariables(void)
   Scr.go.ModifyUSP                          =  True;
   Scr.go.CaptureHonorsStartsOnPage          =  True;
   Scr.go.RecaptureHonorsStartsOnPage        =  False;
-  Scr.go.ActivePlacementHonorsStartsOnPage  =  True;
+  Scr.go.ActivePlacementHonorsStartsOnPage  =  False;
 
   Scr.gs.EmulateMWM = False;
   Scr.gs.EmulateWIN = False;
