@@ -1,4 +1,4 @@
-/****************************************************************************
+      /****************************************************************************
  * This module is all original code
  * by Rob Nation
  * Copyright 1993, Robert Nation
@@ -11,7 +11,7 @@
   Some of the logic comes from pixy2, so the copyright is below.
   */
 /*
- * $Id: Picture.c,v 1.11 1998/11/15 18:00:11 dane Exp $
+ * $Id: Picture.c,v 1.14 1999/01/12 21:07:44 domivogt Exp $
  * Copyright 1996, Romano Giannetti. No guarantees or warantees or anything
  * are provided or implied in any way whatsoever. Use this program at your
  * own risk. Permission to use this program for any purpose is given,
@@ -73,7 +73,7 @@ void InitPictureCMap(Display *dpy,Window Root)
 
 Picture *LoadPicture(Display *dpy,Window Root,char *path, int color_limit)
 {
-  int i,l;
+  int l;
   Picture *p;
 #ifdef XPM
   XpmAttributes xpm_attributes;
@@ -133,7 +133,8 @@ Picture *GetPicture(Display *dpy,Window Root,char *IconPath,char *PixmapPath,
     if(!(path=findIconFile(name,IconPath,R_OK)))
       return NULL;
   p = LoadPicture(dpy,Root,path, color_limit);
-  free(path);
+  if (!p)
+    free(path);
   return p;
 }
 
@@ -144,9 +145,15 @@ Picture *CachePicture(Display *dpy,Window Root,char *IconPath,char *PixmapPath,
   Picture *p=PictureList;
 
   /* First find the full pathname */
+#ifdef XPM
   if(!(path=findIconFile(name,PixmapPath,R_OK)))
     if(!(path=findIconFile(name,IconPath,R_OK)))
       return NULL;
+#else
+  /* Ignore the given pixmap path when compiled without XPM support */
+  if(!(path=findIconFile(name,IconPath,R_OK)))
+    return NULL;
+#endif
 
   /* See if the picture is already cached */
   while(p)
@@ -231,7 +238,7 @@ char *findIconFile(char *icon, char *pathlist, int type)
 
   path = safemalloc(strlen(icon) + l + 10);
   *path = '\0';
-  if (*icon == '/' || pathlist == NULL || *pathlist == '\0') 
+  if (*icon == '/' || pathlist == NULL || *pathlist == '\0')
     {
       /* No search if icon begins with a slash */
       /* No search if pathlist is empty */
