@@ -1,10 +1,12 @@
+#include "config.h"
+
 #include <stdlib.h>
 #include "FvwmIconMan.h"
 #include "x.h"
 #include "xmanager.h"
 
 static char const rcsid[] =
-  "$Id: xmanager.c,v 1.5 1998/11/14 04:40:29 psmith Exp $";
+  "$Id: xmanager.c,v 1.8 1999/01/10 20:59:59 steve Exp $";
 
 #ifdef SHAPE
 #include <X11/extensions/shape.h>
@@ -389,7 +391,7 @@ Button *button_below (WinManager *man, Button *b)
 
 Button *button_right (WinManager *man, Button *b)
 {
-  int i;
+  int i = 0;
 
   if (index_to_col (man, b->index) < man->geometry.cols - 1) {
     i = box_to_index (man, index_to_box (man, b->index) + 1);
@@ -938,8 +940,8 @@ static void get_button_geometry (WinManager *man, Button *button,
   if (man->draw_icons && win && win->pic.picture) {
     /* If no window, then icon_* aren't used, so doesn't matter what
        they are */
-    g->icon_w = MIN (win->pic.width, g->button_h);
-    g->icon_h = MIN (g->button_h - 4, win->pic.height);
+    g->icon_w = min (win->pic.width, g->button_h);
+    g->icon_h = min (g->button_h - 4, win->pic.height);
     icon_pad  = center_padding (g->icon_h, g->button_h);
     g->icon_x = g->button_x + 4;
     g->icon_y = g->button_y + icon_pad;
@@ -1712,8 +1714,13 @@ void man_exposed (WinManager *man, XEvent *theEvent)
      but avoids having to match which expose event results from which shape
      change */
 
-  for (i = 0; i < man->buttons.num_windows; i++) {
-    bp[i]->drawn_state.dirty_flags |= REDRAW_BUTTON;
+  if (man->buttons.num_windows) {
+    for (i = 0; i < man->buttons.num_windows; i++) {
+      bp[i]->drawn_state.dirty_flags |= REDRAW_BUTTON;
+    }
+  }
+  else {
+    draw_empty_manager (man);
   }
 
   return;
