@@ -20,15 +20,6 @@
 #include "../../fvwm/module.h"
 
 
-#ifdef BROKEN_SUN_HEADERS
-#include "../../fvwm/sun_headers.h"
-#endif
-
-#ifdef NEEDS_ALPHA_HEADER
-#include "../../fvwm/alpha_header.h"
-#endif /* NEEDS_ALPHA_HEADER */
-
-
 /******************************************************************************
   InitList - Initialize the list
 ******************************************************************************/
